# FitTrackee
**A simple self-hosted workout/activity tracker.**  

[![Python Version](https://img.shields.io/badge/python-3.7+-brightgreen.svg)](https://python.org)
[![Flask Version](https://img.shields.io/badge/flask-1.1-brightgreen.svg)](http://flask.pocoo.org/) 
[![code style: black](https://img.shields.io/badge/code%20style-black-black)](https://github.com/psf/black) 
[![React Version](https://img.shields.io/badge/react-17.0-brightgreen.svg)](https://reactjs.org/) 
[![code style: prettier](https://img.shields.io/badge/code_style-prettier-ff69b4.svg)](https://github.com/prettier/prettier)  
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/290a285f22e94132904dc13b4dd19d1d)](https://www.codacy.com/app/SamR1/FitTrackee)
[![pipeline status](https://gitlab.com/SamR1/FitTrackee/badges/master/pipeline.svg)](https://gitlab.com/SamR1/FitTrackee/-/commits/master) <sup><sup>1</sup></sup>
[![coverage report](https://gitlab.com/SamR1/FitTrackee/badges/master/coverage.svg)](https://gitlab.com/SamR1/FitTrackee/-/commits/master)

---

This web application allows you to track your outdoor activities from gpx files and keep your data on your own server.  
No mobile app is developed yet, but several existing mobile apps can store workouts data locally and export them into a gpx file.  
Examples (for Android):  
* [Runner Up](https://github.com/jonasoreland/runnerup) (GPL v3)  
* [ForRunners](https://gitlab.com/brvier/ForRunners) (GPL v3)  
* [OpenTracks](https://github.com/OpenTracksApp/OpenTracks) (Apache License)  
* [FitoTrack](https://codeberg.org/jannis/FitoTrack) (GPL v3)  
* [AlpineQuest](https://www.alpinequest.net/) (Proprietary, no trackers according to [exodus privay report](https://reports.exodus-privacy.eu.org/en/reports/search/psyberia.alpinequest.free/))  

Maps are displayed using [Open Street Map](https://www.openstreetmap.org).  
It is also possible to add a workout without a gpx file.

**Still under heavy development (some features may be unstable).**  
(see [issues](https://github.com/SamR1/FitTrackee/issues) and [documentation](https://samr1.github.io/FitTrackee) for more information)  

![FitTrackee Dashboard Screenshot](https://samr1.github.io/FitTrackee/_images/fittrackee_screenshot-01.png)

---

Notes:  
_1. Test coverage: only for Python API_
